# Test Fonts

All `.kbits` files copy from [bitsnpicas/fonts/macintosh](https://github.com/kreativekorp/bitsnpicas/tree/master/fonts/macintosh).

All `.kbitx` files convert from the same name `.kbits` files by [bitsnpicas-spec/demo](../../bitsnpicas-spec/demo).
